==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/dialogs/dlgeditaction.cpp <==
/***************************************************************************
                          dlgeditaction.cpp  -  Edit Action
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : St nov 6 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@host.sk
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "../dialogs/dlgeditaction.h"

#include "../caction.h"

#include <qlayout.h>
#include <qlabel.h>
#include <qwhatsthis.h>
#include <qcheckbox.h>

#include <kicondialog.h>
#include <klocale.h>
#include <klineedit.h>

dlgEditAction::dlgEditAction (cAction *a, QWidget *parent, const char *name) :
    KDialogBase (parent, name, true, i18n ("Edit action"), Ok|Cancel, Ok)
{
  action = a;

  createDialog ();
  updateActionDialog(false);
}

void dlgEditAction::createDialog ()
{
  //initial dialog size
  setInitialSize (QSize (300, 250));

  //create main dialog's widget
  QWidget *page = new QWidget (this);
  QGridLayout *layout = new QGridLayout (page, 4, 2);

  setMainWidget (page);

  //label
  QLabel *ll = new QLabel (i18n ("&Label"), page);
  label = new KLineEdit (page);
  ll->setBuddy (label);

  QWhatsThis::add (label, i18n ("Label of the current action."));

  //command
  QLabel *cl = new QLabel (i18n ("&Command"), page);
  cmd = new KLineEdit (page);
  cl->setBuddy (cmd);
  QWhatsThis::add (cmd, i18n ("Command that will be executed if you click on the button. "
          "Note that you can enter multiple commands here (separated by semi-colons, "
          "or another characted defined in <b>global settings</b>)."));

  //icon
  QLabel *il = new QLabel ("&Icon", page);
  icon = new KIconButton (page);
  icon->setIconSize (32);
  il->setBuddy (icon);
  QWhatsThis::add (icon, i18n ("Icon on toolbar button, that represents this action."));
  
  toggler = new QCheckBox (i18n ("Make this button a push-down button"), page);
  QWhatsThis::add (toggler, i18n ("Turns this button into a push-down button, allowing you to send "
          "a set of commands on enabling it and disabling it."));
  connect(toggler, SIGNAL (toggled(bool)), this, SLOT (updateActionDialog(bool)));
  
  QLabel *c2l = new QLabel (i18n ("&Un-press command"), page);
  cmd2 = new KLineEdit (page);
  c2l ->setBuddy (cmd2);
  QWhatsThis::add (cmd2, i18n ("Command that will be executed if you click on push-down button "
          "that is pushed."));

  //place'em there!
  layout->setSpacing (5);
  layout->addWidget (ll, 0, 0);
  layout->addWidget (label, 0, 1);
  layout->addWidget (cl, 1, 0);
  layout->addWidget (cmd, 1, 1);
  layout->addWidget (il, 2, 0);
  layout->addWidget (icon, 2, 1);
  layout->addMultiCellWidget (toggler, 3, 3, 0, 1);
  layout->addWidget (c2l, 4, 0);
  layout->addWidget (cmd2, 4, 1);
  layout->setRowStretch (3, 5);
}

dlgEditAction::~dlgEditAction ()
{

}

bool dlgEditAction::showMe ()
//fills and shows the dialog, then applies changes if needed
{
  //fill in the dialog
  label->setText (action->getCaption ());
  cmd->setText (action->getCommand ());
  icon->setIcon (action->getIconName ());

  //show it!
  int n = exec ();

  //update structure if needed
  if (n == Accepted)
  {
    action->setCaption (label->text ());
    action->setCommand (cmd->text ());
    action->setIconName (icon->icon ());
    action->setCommand2 (cmd2->text ());
    action->setPushDown (toggler->isChecked());
    return true;
  }
  else
    return false;
}

void dlgEditAction::updateActionDialog(bool how)
{
  cmd2->setEnabled(how);
}

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/dialogs/dlgeditaction.cpp <==
/***************************************************************************
                          dlgeditaction.cpp  -  Edit Action
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : St nov 6 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "dlgeditaction.h"

#include "caction.h"

#include <qlayout.h>
#include <qlabel.h>
#include <qwhatsthis.h>
#include <qcheckbox.h>

#include <kicondialog.h>
#include <klocale.h>
#include <klineedit.h>

dlgEditAction::dlgEditAction (cAction *a, QWidget *parent, const char *name) :
    KDialogBase (parent, name, true, i18n ("Edit action"), Ok|Cancel, Ok)
{
  action = a;

  createDialog ();
  updateActionDialog(false);
}

void dlgEditAction::createDialog ()
{
  //initial dialog size
  setInitialSize (QSize (300, 250));

  //create main dialog's widget
  QWidget *page = new QWidget (this);
  QGridLayout *layout = new QGridLayout (page, 4, 2);

  setMainWidget (page);

  //label
  QLabel *ll = new QLabel (i18n ("&Label"), page);
  label = new KLineEdit (page);
  ll->setBuddy (label);

  QWhatsThis::add (label, i18n ("Label of the current action."));

  //command
  QLabel *cl = new QLabel (i18n ("&Command"), page);
  cmd = new KLineEdit (page);
  cl->setBuddy (cmd);
  QWhatsThis::add (cmd, i18n ("Command that will be executed if you click on the button. "
          "Note that you can enter multiple commands here (separated by semi-colons, "
          "or another characted defined in <b>global settings</b>)."));

  //icon
  QLabel *il = new QLabel ("&Icon", page);
  icon = new KIconButton (page);
  icon->setIconSize (32);
  il->setBuddy (icon);
  QWhatsThis::add (icon, i18n ("Icon on toolbar button, that represents this action."));
  
  toggler = new QCheckBox (i18n ("Make this button a push-down button"), page);
  QWhatsThis::add (toggler, i18n ("Turns this button into a push-down button, allowing you to send "
          "a set of commands on enabling it and disabling it."));
  connect(toggler, SIGNAL (toggled(bool)), this, SLOT (updateActionDialog(bool)));
  
  QLabel *c2l = new QLabel (i18n ("&Un-press command"), page);
  cmd2 = new KLineEdit (page);
  c2l ->setBuddy (cmd2);
  QWhatsThis::add (cmd2, i18n ("Command that will be executed if you click on push-down button "
          "that is pushed."));

  //place'em there!
  layout->setSpacing (5);
  layout->addWidget (ll, 0, 0);
  layout->addWidget (label, 0, 1);
  layout->addWidget (cl, 1, 0);
  layout->addWidget (cmd, 1, 1);
  layout->addWidget (il, 2, 0);
  layout->addWidget (icon, 2, 1);
  layout->addMultiCellWidget (toggler, 3, 3, 0, 1);
  layout->addWidget (c2l, 4, 0);
  layout->addWidget (cmd2, 4, 1);
  layout->setRowStretch (3, 5);
}

dlgEditAction::~dlgEditAction ()
{

}

bool dlgEditAction::showMe ()
//fills and shows the dialog, then applies changes if needed
{
  //fill in the dialog
  label->setText (action->getCaption ());
  cmd->setText (action->getCommand ());
  icon->setIcon (action->getIconName ());

  //show it!
  int n = exec ();

  //update structure if needed
  if (n == Accepted)
  {
    action->setCaption (label->text ());
    action->setCommand (cmd->text ());
    action->setIconName (icon->icon ());
    action->setCommand2 (cmd2->text ());
    action->setPushDown (toggler->isChecked());
    return true;
  }
  else
    return false;
}

void dlgEditAction::updateActionDialog(bool how)
{
  cmd2->setEnabled(how);
}
